<?php
session_start();
require_once '../registration-form-112724/connect.php';
require_once '../registration-form-112724/global.php';


// Redirect logged in users
if (isLoggedIn()) {
    header("Location: dashboard.php");
    exit();
}

// Process login form submission
$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = sanitizeInput($_POST['email']);
    $password = $_POST['password']; // Don't sanitize passwords

    if (!$conn) {
        error_log("Database connection failed."); // Log error
        $error = "Database connection failed.";
    } else {
        $user = authenticateUser($email, $password, $conn);

        if ($user && password_verify($password, $user['password'])) { // Ensure password_verify is used
            // Set session variables
            $_SESSION['user_id'] = $user['id'];
            $_SESSION['user_email'] = $user['email'];
            $_SESSION['user_name'] = $user['first_name'] . ' ' . $user['last_name'];
            $_SESSION['logged_in'] = true;

            // Redirect to dashboard
            header("Location: dashboard.php");
            exit();
        } else {
            error_log("Invalid login attempt for email: $email"); // Log invalid login
            $error = "Invalid email or password.";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login - USA Legacy Grant</title>
    <style>
        /* [Use the same styles as in register.php for consistency] */
        body {
            margin: 0;
            padding: 0;
            font-family: Arial, sans-serif;
            background-image: url('https://images.unsplash.com/photo-1451187580459-43490279c0fa?ixlib=rb-1.2.1&auto=format&fit=crop&w=1352&q=80');
            background-size: cover;
            background-position: center;
            background-attachment: fixed;
            min-height: 100vh;
            display: flex;
            flex-direction: column;
        }
        
        .login-container {
            max-width: 400px;
            margin: 50px auto;
            background-color: #ffffffd1;
            padding: 40px;
            border-radius: 8px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
        }
        
        .login-header {
            text-align: center;
            margin-bottom: 30px;
        }
        
        .login-header h1 {
            color: #0066cc;
            margin-bottom: 10px;
        }
        
        .form-group {
            margin-bottom: 20px;
        }
        
        .form-group label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
        }
        
        .form-group input {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 16px;
        }
        
        .form-submit {
            text-align: center;
            margin-top: 30px;
        }
        
        .form-submit button {
            background-color: #0066cc;
            color: white;
            border: none;
            padding: 12px 30px;
            font-size: 16px;
            border-radius: 4px;
            cursor: pointer;
        }
        
        .error-message {
            color: #d9534f;
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
            padding: 10px;
            border-radius: 4px;
            margin-bottom: 20px;
            text-align: center;
        }
        
        .register-link {
            text-align: center;
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <header class="header">
        <div class="logo">
            <a href="../front-page-121824/index.html">
                <img src="../wp-content/themes/trevor-base-theme/assets/images/USA-Legacy-Grant-Logo.png" alt="Website Logo">
            </a>
        </div>
    </header>
    
    <div class="login-container">
        <div class="login-header">
            <h1>Member Login</h1>
            <p>Please enter your credentials to access your account</p>
        </div>
        
        <?php if (!empty($error)): ?>
            <div class="error-message"><?php echo $error; ?></div>
        <?php endif; ?>
        
        <form method="post">
            <div class="form-group">
                <label for="email">Email Address</label>
                <input type="email" id="email" name="email" required>
            </div>
            
            <div class="form-group">
                <label for="password">Password</label>
                <input type="password" id="password" name="password" required>
            </div>
            
            <div class="form-submit">
                <button type="submit">Login</button>
            </div>
            
            <div class="register-link">
                Don't have an account? <a href="register.php">Register here</a>
            </div>
        </form>
    </div>
</body>
</html>