<?php
// Database configuration
$db_host = 'localhost';
$db_username = 'root'; // Default XAMPP username
$db_password = ''; // Default XAMPP password is empty
$db_name = 'legacy2'; // Change to your database name

// Connect to MySQL database
$conn = mysqli_connect($db_host, $db_username, $db_password, $db_name);

// Check connection
if (!$conn) {
    die("Connection failed: " . mysqli_connect_error());
}

// Initialize variables
$errors = [];
$success = false;

// Process form when submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['submit'])) {
    // Validate and sanitize inputs
    $first_name = mysqli_real_escape_string($conn, $_POST['first_name']);
    $last_name = mysqli_real_escape_string($conn, $_POST['last_name']);
    $dob = mysqli_real_escape_string($conn, $_POST['dob']);
    $gender = mysqli_real_escape_string($conn, $_POST['gender']);
    $email = mysqli_real_escape_string($conn, $_POST['email']);
    $confirm_email = mysqli_real_escape_string($conn, $_POST['confirm_email']);
    $phone = mysqli_real_escape_string($conn, $_POST['phone']);
    $occupation = mysqli_real_escape_string($conn, $_POST['occupation']);
    $address = mysqli_real_escape_string($conn, $_POST['address']);
    $city = mysqli_real_escape_string($conn, $_POST['city']);
    $state = mysqli_real_escape_string($conn, $_POST['state']);
    $zip = mysqli_real_escape_string($conn, $_POST['zip']);
    $password = $_POST['password'];
    $confirm_password = $_POST['confirm_password'];
    $us_citizen = isset($_POST['us_citizen']) ? (int)$_POST['us_citizen'] : 0;
    $terms = isset($_POST['terms']) ? 1 : 0;
    $marketing = isset($_POST['marketing']) ? 1 : 0;

    // Validate email match
    if ($email !== $confirm_email) {
        $errors[] = "Email addresses do not match.";
    }

    // Validate password match
    if ($password !== $confirm_password) {
        $errors[] = "Passwords do not match.";
    }

    // Validate password strength
    if (strlen($password) < 8 || !preg_match('/[0-9]/', $password) || !preg_match('/[^A-Za-z0-9]/', $password)) {
        $errors[] = "Password must be at least 8 characters long and contain at least one number and one special character.";
    }

    // Check if email already exists
    $email_check = "SELECT * FROM users WHERE email = '$email'";
    $result = mysqli_query($conn, $email_check);
    if (mysqli_num_rows($result) > 0) {
        $errors[] = "Email address is already registered.";
    }

    // Convert date format for MySQL
    $dob_mysql = date('Y-m-d', strtotime($dob));

    // Hash password
    $password_hash = password_hash($password, PASSWORD_DEFAULT);

    // If no errors, insert into database
    if (empty($errors)) {
        $sql = "INSERT INTO users (
            first_name, last_name, date_of_birth, gender, email, phone, 
            occupation, address, city, state, zip_code, password_hash, 
            is_us_citizen, agreed_to_terms, agreed_to_marketing
        ) VALUES (
            '$first_name', '$last_name', '$dob_mysql', '$gender', '$email', '$phone', 
            '$occupation', '$address', '$city', '$state', '$zip', '$password_hash', 
            $us_citizen, $terms, $marketing
        )";

        if (mysqli_query($conn, $sql)) {
            $success = true;
            // You might want to redirect here
            // header("Location: success.php");
            // exit();
        } else {
            $errors[] = "Error: " . $sql . "<br>" . mysqli_error($conn);
        }
    }
}

// Close connection
mysqli_close($conn);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registration Result</title>
    <style>
        .error { color: red; }
        .success { color: green; }
    </style>
</head>
<body>
    <?php if (!empty($errors)): ?>
        <div class="error">
            <h3>Error(s) occurred:</h3>
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo htmlspecialchars($error); ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
        <p><a href="javascript:history.back()">Go back to fix errors</a></p>
    <?php elseif ($success): ?>
        <div class="success">
            <h3>Registration Successful!</h3>
            <p>Thank you for registering, <?php echo htmlspecialchars($first_name); ?>!</p>
            <p><a href="login.php">Proceed to login</a></p>
        </div>
    <?php endif; ?>
</body>
</html>