<?php
require_once 'global.php';
require_once 'connect.php';

// Initialize variables
$error = '';
$success = '';
$formData = [
    'first-name' => '',
    'last-name' => '',
    'dob' => '',
    'gender' => '',
    'email' => '',
    'phone' => '',
    'occupation' => '',
    'address' => '',
    'city' => '',
    'state' => '',
    'zip' => ''
];

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize and validate input
    $formData = sanitizeInput($_POST);
    
    // Validate required fields
    $validationErrors = validateRegistrationForm($formData);
    
    if (empty($validationErrors)) {
        // Check if email already exists
        if (emailExists($formData['email'], $conn)) {
            $error = "This email address is already registered.";
        } else {
            // Hash password
            $hashedPassword = password_hash($formData['password'], PASSWORD_DEFAULT);
            
            // Insert into database
            if (registerUser($formData, $hashedPassword, $conn)) {
                $success = "Registration successful! You can now login to your account.";
                // Clear form data
                $formData = array_fill_keys(array_keys($formData), '');
            } else {
                $error = "There was an error processing your registration. Please try again.";
            }
        }
    } else {
        $error = implode("<br>", $validationErrors);
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="icon" type="image/png" href="../wp-content/themes/trevor-base-theme/assets/Icon-Images/favicon.png">
    <title>Registration Form</title>
    <style>
        * {
            box-sizing: border-box;
            font-family: Arial, sans-serif;
        }
        
        body {
            margin: 0;
            padding: 0;
            color: #333;
            background-image: url('https://images.unsplash.com/photo-1451187580459-43490279c0fa?ixlib=rb-1.2.1&auto=format&fit=crop&w=1352&q=80');
            background-size: cover;
            background-position: center;
            background-attachment: fixed;
            background-repeat: no-repeat;
            position: relative;
            min-height: 100vh;
            display: flex;
            flex-direction: column;
        }
 
        .header {
            background-color: rgba(255, 255, 255, 0.2);
            padding: 20px 0;
            backdrop-filter: blur(10px);
            text-align: center;
            width: 100%;
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 15px 20px;
        }

        .logo {
            color: white;
            font-size: 2rem;
            font-weight: bold;
            text-shadow: 2px 2px 4px rgba(0, 0, 0, 0.5);
        }

        .logo img {
            height: 50px;
        }

        .login-button {
            padding: 8px 20px;
            background-color: #0073aa;
            color: white;
            text-decoration: none;
            border-radius: 4px;
            font-weight: bold;
        }

        .login-button:hover {
            background-color: #005a87;
        }

        body::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: rgba(255, 255, 255, 0);
            z-index: -1;
        }
        
        .container {
            max-width: 1000px;
            margin: 0 auto;
            padding: 20px;
            flex: 1;
        }
        
        .registration-form {
            background-color: #ffffffd1;
            border-radius: 8px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
            padding: 40px;
            margin: 30px auto;
        }
        
        .form-header {
            text-align: center;
            margin-bottom: 30px;
            background-image: linear-gradient(rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.5)), url('../wp-content/themes/trevor-base-theme/assets/images/new-york.jpg');
            background-size: cover;
            background-position: center;
            padding: 30px 20px;
            border-radius: 8px 8px 0 0;
        }
               
        .form-header h1 {
            color: #0066cc;
            margin-bottom: 10px;
            font-size: 32px;
        }
        
        .form-header p {
            color: #ffffff;
            font-size: 16px;
        }
        
        .form-row {
            display: flex;
            flex-wrap: wrap;
            margin-bottom: 20px;
        }
        
        .form-group {
            flex: 1;
            min-width: 250px;
            margin-right: 15px;
            margin-bottom: 15px;
        }
        
        .form-group:last-child {
            margin-right: 0;
        }
        
        .form-group label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
            color: #555;
        }
        
        .form-group input[type="text"],
        .form-group input[type="email"],
        .form-group input[type="tel"],
        .form-group input[type="password"],
        .form-group select,
        .form-group textarea {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 16px;
            transition: border-color 0.3s;
        }
        
        .form-group input[type="text"]:focus,
        .form-group input[type="email"]:focus,
        .form-group input[type="tel"]:focus,
        .form-group input[type="password"]:focus,
        .form-group select:focus,
        .form-group textarea:focus {
            border-color: #0066cc;
            outline: none;
            box-shadow: 0 0 5px rgba(0, 102, 204, 0.3);
        }
        
        .form-group input[type="checkbox"] {
            margin-right: 10px;
        }
        
        .form-group .checkbox-label {
            display: inline;
            font-weight: normal;
        }
        
        .form-submit {
            text-align: center;
            margin-top: 30px;
            width: 100%;
        }
        
        .form-submit button {
            background-color: #0066cc;
            color: white;
            border: none;
            padding: 14px 40px;
            font-size: 18px;
            border-radius: 4px;
            cursor: pointer;
            transition: all 0.3s;
        }
        
        .form-submit button:hover {
            background-color: #0052a3;
            transform: translateY(-2px);
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
        }
        
        .required-field::after {
            content: " *";
            color: red;
        }
        
        .password-requirements {
            font-size: 14px;
            color: #666;
            margin-top: 5px;
        }
        
        .disclaimer {
            font-size: 14px;
            text-align: center;
            color: #666;
            margin-top: 30px;
            padding-top: 20px;
            border-top: 1px solid #eee;
            line-height: 1.6;
        }

        .footer {
            background-color: slategrey;
            padding: 20px;
            text-align: center;
            color: white;
            width: 100%;
            margin-top: auto;
        }
        
        .error-message {
            color: #d9534f;
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
            padding: 10px;
            border-radius: 4px;
            margin-bottom: 20px;
            text-align: center;
        }
        
        .success-message {
            color: #155724;
            background-color: #d4edda;
            border: 1px solid #c3e6cb;
            padding: 10px;
            border-radius: 4px;
            margin-bottom: 20px;
            text-align: center;
        }
        
        @media (max-width: 768px) {
            .form-group {
                flex: 100%;
                margin-right: 0;
            }
            
            .registration-form {
                padding: 25px;
            }
            
            .form-header h1 {
                font-size: 28px;
            }
            
            .form-submit {
                display: flex;
                justify-content: center;
            }
        }
        
        @media (max-width: 480px) {
            .container {
                padding: 10px;
            }
            
            .registration-form {
                padding: 20px;
                margin: 15px auto;
            }
            
            .form-header h1 {
                font-size: 24px;
            }
        }
    </style>
</head>
<body>
    <header class="header">
        <div class="logo">
            <a href="../front-page-121824/index.html">
                <img src="../wp-content/themes/trevor-base-theme/assets/images/USA-Legacy-Grant-Logo.png" alt="Website Logo">
            </a>
        </div>
        <div class="header-right">
            <a href="../Login/login.php" class="login-button">Member Login</a>
        </div>
    </header>
    
    <div class="container">
        <form class="registration-form" action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']); ?>" method="post">
            <div class="form-header">
                <h1>Create an Account</h1>
                <p>Please fill in the information below to start your application.</p>
            </div>
            
            <?php if (!empty($error)): ?>
                <div class="error-message"><?php echo $error; ?></div>
            <?php endif; ?>
            
            <?php if (!empty($success)): ?>
                <div class="success-message"><?php echo $success; ?></div>
            <?php endif; ?>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="first-name">First Name</label>
                    <input type="text" id="first-name" name="first-name" value="<?php echo htmlspecialchars($formData['first-name']); ?>" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="last-name">Last Name</label>
                    <input type="text" id="last-name" name="last-name" value="<?php echo htmlspecialchars($formData['last-name']); ?>" required>
                </div>
            </div>

            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="dob">Date of Birth</label>
                    <input type="text" id="dob" name="dob" placeholder="MM/DD/YYYY" value="<?php echo htmlspecialchars($formData['dob']); ?>" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="gender">Gender</label>
                    <input type="text" id="gender" name="gender" placeholder="Male or Female" value="<?php echo htmlspecialchars($formData['gender']); ?>" required>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="email">Email Address</label>
                    <input type="email" id="email" name="email" value="<?php echo htmlspecialchars($formData['email']); ?>" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="confirm-email">Confirm Email Address</label>
                    <input type="email" id="confirm-email" name="confirm-email" value="<?php echo htmlspecialchars($formData['email']); ?>" required>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="phone">Phone Number</label>
                    <input type="tel" id="phone" name="phone" value="<?php echo htmlspecialchars($formData['phone']); ?>" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="occupation">Occupation</label>
                    <input type="text" id="occupation" name="occupation" value="<?php echo htmlspecialchars($formData['occupation']); ?>" required>
                </div>
            </div>
                                    
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="address">Home Address</label>
                    <input type="text" id="address" name="address" value="<?php echo htmlspecialchars($formData['address']); ?>" required>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="city">City</label>
                    <input type="text" id="city" name="city" value="<?php echo htmlspecialchars($formData['city']); ?>" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="state">State</label>
                    <select id="state" name="state" required>
                        <option value="">Select State</option>
                        <option value="AL" <?php echo ($formData['state'] == 'AL') ? 'selected' : ''; ?>>Alabama</option>
                        <option value="AK" <?php echo ($formData['state'] == 'AK') ? 'selected' : ''; ?>>Alaska</option>
                        <option value="AZ" <?php echo ($formData['state'] == 'AZ') ? 'selected' : ''; ?>>Arizona</option>
                        <option value="AR" <?php echo ($formData['state'] == 'AR') ? 'selected' : ''; ?>>Arkansas</option>
                        <option value="CA" <?php echo ($formData['state'] == 'CA') ? 'selected' : ''; ?>>California</option>
                        <option value="CO" <?php echo ($formData['state'] == 'CO') ? 'selected' : ''; ?>>Colorado</option>
                        <option value="CT" <?php echo ($formData['state'] == 'CT') ? 'selected' : ''; ?>>Connecticut</option>
                        <option value="DE" <?php echo ($formData['state'] == 'DE') ? 'selected' : ''; ?>>Delaware</option>
                        <option value="FL" <?php echo ($formData['state'] == 'FL') ? 'selected' : ''; ?>>Florida</option>
                        <option value="GA" <?php echo ($formData['state'] == 'GA') ? 'selected' : ''; ?>>Georgia</option>
                        <option value="HI" <?php echo ($formData['state'] == 'HI') ? 'selected' : ''; ?>>Hawaii</option>
                        <option value="ID" <?php echo ($formData['state'] == 'ID') ? 'selected' : ''; ?>>Idaho</option>
                        <option value="IL" <?php echo ($formData['state'] == 'IL') ? 'selected' : ''; ?>>Illinois</option>
                        <option value="IN" <?php echo ($formData['state'] == 'IN') ? 'selected' : ''; ?>>Indiana</option>
                        <option value="IA" <?php echo ($formData['state'] == 'IA') ? 'selected' : ''; ?>>Iowa</option>
                        <option value="KS" <?php echo ($formData['state'] == 'KS') ? 'selected' : ''; ?>>Kansas</option>
                        <option value="KY" <?php echo ($formData['state'] == 'KY') ? 'selected' : ''; ?>>Kentucky</option>
                        <option value="LA" <?php echo ($formData['state'] == 'LA') ? 'selected' : ''; ?>>Louisiana</option>
                        <option value="ME" <?php echo ($formData['state'] == 'ME') ? 'selected' : ''; ?>>Maine</option>
                        <option value="MD" <?php echo ($formData['state'] == 'MD') ? 'selected' : ''; ?>>Maryland</option>
                        <option value="MA" <?php echo ($formData['state'] == 'MA') ? 'selected' : ''; ?>>Massachusetts</option>
                        <option value="MI" <?php echo ($formData['state'] == 'MI') ? 'selected' : ''; ?>>Michigan</option>
                        <option value="MN" <?php echo ($formData['state'] == 'MN') ? 'selected' : ''; ?>>Minnesota</option>
                        <option value="MS" <?php echo ($formData['state'] == 'MS') ? 'selected' : ''; ?>>Mississippi</option>
                        <option value="MO" <?php echo ($formData['state'] == 'MO') ? 'selected' : ''; ?>>Missouri</option>
                        <option value="MT" <?php echo ($formData['state'] == 'MT') ? 'selected' : ''; ?>>Montana</option>
                        <option value="NE" <?php echo ($formData['state'] == 'NE') ? 'selected' : ''; ?>>Nebraska</option>
                        <option value="NV" <?php echo ($formData['state'] == 'NV') ? 'selected' : ''; ?>>Nevada</option>
                        <option value="NH" <?php echo ($formData['state'] == 'NH') ? 'selected' : ''; ?>>New Hampshire</option>
                        <option value="NJ" <?php echo ($formData['state'] == 'NJ') ? 'selected' : ''; ?>>New Jersey</option>
                        <option value="NM" <?php echo ($formData['state'] == 'NM') ? 'selected' : ''; ?>>New Mexico</option>
                        <option value="NY" <?php echo ($formData['state'] == 'NY') ? 'selected' : ''; ?>>New York</option>
                        <option value="NC" <?php echo ($formData['state'] == 'NC') ? 'selected' : ''; ?>>North Carolina</option>
                        <option value="ND" <?php echo ($formData['state'] == 'ND') ? 'selected' : ''; ?>>North Dakota</option>
                        <option value="OH" <?php echo ($formData['state'] == 'OH') ? 'selected' : ''; ?>>Ohio</option>
                        <option value="OK" <?php echo ($formData['state'] == 'OK') ? 'selected' : ''; ?>>Oklahoma</option>
                        <option value="OR" <?php echo ($formData['state'] == 'OR') ? 'selected' : ''; ?>>Oregon</option>
                        <option value="PA" <?php echo ($formData['state'] == 'PA') ? 'selected' : ''; ?>>Pennsylvania</option>
                        <option value="RI" <?php echo ($formData['state'] == 'RI') ? 'selected' : ''; ?>>Rhode Island</option>
                        <option value="SC" <?php echo ($formData['state'] == 'SC') ? 'selected' : ''; ?>>South Carolina</option>
                        <option value="SD" <?php echo ($formData['state'] == 'SD') ? 'selected' : ''; ?>>South Dakota</option>
                        <option value="TN" <?php echo ($formData['state'] == 'TN') ? 'selected' : ''; ?>>Tennessee</option>
                        <option value="TX" <?php echo ($formData['state'] == 'TX') ? 'selected' : ''; ?>>Texas</option>
                        <option value="UT" <?php echo ($formData['state'] == 'UT') ? 'selected' : ''; ?>>Utah</option>
                        <option value="VT" <?php echo ($formData['state'] == 'VT') ? 'selected' : ''; ?>>Vermont</option>
                        <option value="VA" <?php echo ($formData['state'] == 'VA') ? 'selected' : ''; ?>>Virginia</option>
                        <option value="WA" <?php echo ($formData['state'] == 'WA') ? 'selected' : ''; ?>>Washington</option>
                        <option value="WV" <?php echo ($formData['state'] == 'WV') ? 'selected' : ''; ?>>West Virginia</option>
                        <option value="WI" <?php echo ($formData['state'] == 'WI') ? 'selected' : ''; ?>>Wisconsin</option>        
                        <option value="WY" <?php echo ($formData['state'] == 'WY') ? 'selected' : ''; ?>>Wyoming</option>
                    </select>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="zip">Zip Code</label>
                    <input type="text" id="zip" name="zip" value="<?php echo htmlspecialchars($formData['zip']); ?>" required>
                </div>
            </div>

            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="password">Password</label>
                    <input type="password" id="password" name="password" required>
                    <div class="password-requirements">
                        Password must be at least 8 characters long and contain at least one number and one special character.
                    </div>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="confirm-password">Confirm Password</label>
                    <input type="password" id="confirm-password" name="confirm-password" required>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field">Are you a U.S. Citizen?</label>
                    <div>
                        <input type="radio" id="citizen-yes" name="citizen" value="yes" <?php echo (isset($_POST['citizen']) && $_POST['citizen'] == 'yes') ? 'checked' : ''; ?> required>
                        <label class="checkbox-label" for="citizen-yes">Yes</label>
                        
                        <input type="radio" id="citizen-no" name="citizen" value="no" <?php echo (isset($_POST['citizen']) && $_POST['citizen'] == 'no') ? 'checked' : ''; ?>>
                        <label class="checkbox-label" for="citizen-no">No</label>
                    </div>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <input type="checkbox" id="terms" name="terms" <?php echo (isset($_POST['terms'])) ? 'checked' : ''; ?> required>
                    <label class="checkbox-label required-field" for="terms">
                        I agree to the <a href="/terms-of-service">Terms of Service</a> and 
                        <a href="/privacy-policy" style="color: blue;">Privacy Policy</a>
                    </label>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <input type="checkbox" id="marketing" name="marketing" <?php echo (isset($_POST['marketing'])) ? 'checked' : ''; ?>>
                    <label class="checkbox-label" for="marketing">I agree to receive marketing communications</label>
                </div>
            </div>
            
            <div class="form-submit">
                <button type="submit">Submit</button>
            </div>
            
            <div class="disclaimer">
                <p>By creating an account, you agree to our Terms of Service and acknowledge that you have read our Privacy Policy. Your information will be used in accordance with our Privacy Policy.</p>
            </div>
        </form>
    </div>
    <footer class="footer">
        &copy; <span id="year"></span> USA Legacy Grant. All Rights Reserved. | <a href="#">Privacy Policy</a>
    </footer>

    <script>
        document.getElementById("year").textContent = new Date().getFullYear();
    </script>
</body>
</html>